RSP
-------

Main
^^^^^^^^^^^^^^^^

*rsp_process()*
"""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_process

*rsp_analyze()*
"""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_analyze

*rsp_simulate()*
""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_simulate

*rsp_plot()*
"""""""""""""
.. autofunction:: neurokit2.rsp.rsp_plot


Preprocessing
^^^^^^^^^^^^^^^^
*rsp_clean()*
"""""""""""""
.. autofunction:: neurokit2.rsp.rsp_clean

*rsp_amplitude()*
"""""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_amplitude

*rsp_peaks()*
"""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_peaks

*rsp_findpeaks()*
"""""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_findpeaks

*rsp_fixpeaks()*
""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_fixpeaks

*rsp_phase()*
"""""""""""""
.. autofunction:: neurokit2.rsp.rsp_phase

*rsp_rate()*
""""""""""""
.. autofunction:: neurokit2.rsp.rsp_rate

*rsp_symmetry()*
"""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_symmetry

*rsp_rrv()*
"""""""""""
.. autofunction:: neurokit2.rsp.rsp_rrv

*rsp_rvt()*
"""""""""""""
.. autofunction:: neurokit2.rsp.rsp_rvt


Analysis
^^^^^^^^^
*rsp_eventrelated()*
""""""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_eventrelated

*rsp_intervalrelated()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.rsp.rsp_intervalrelated



*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*

.. automodule:: neurokit2.rsp
   :members:
   :exclude-members: rsp_process, rsp_analyze, rsp_plot, rsp_clean, rsp_amplitude, rsp_findpeaks, rsp_fixpeaks, rsp_peaks, rsp_phase, rsp_rate, rsp_rrv, rsp_eventrelated, rsp_intervalrelated, rsp_simulate, rsp_rvt, rsp_symmetry